@@ -340,6 +340,33 @@ class MAGICINFO_CONTENT_ORIENTATION(Command):
     DATA = [_COMMON.ORIENTATION_MODE_STATE]
 
 
+class SET_CONTENT_DOWNLOAD(Command):
+    """
+    Control the device URL of content download.
+    The device will download content (images, schedules) from the specified URL.
+
+    Working Condition:
+    - Depends on each model spec it will be supported or not.
+    - Supports ePaper displays (e.g., EM32DX) and Smart Signage displays.
+    - Device must have network connectivity to the content server.
+
+    CONTENT_URL: ASCII code data for the content server address.
+    The URL should point to a content server that provides:
+    - Content manifest (content.json) with schedule and media references
+    - Media files (images) accessible via URLs in the manifest
+
+    Example: "http://192.168.1.100:6868/content.json"
+
+    Note: This command is used for mobile-to-display content transfer and
+    automated content management for digital signage.
+    """
+    CMD = 0xC7
+    SUBCMD = 0x53
+    GET, SET = False, True
+
+    DATA = [StrCoded(0x80, 'CONTENT_URL')]
+
+
 class MDC_CONNECTION(Command):
     """
     Note: Depends on the product specification,
@@ -691,7 +718,7 @@ class DEVICE_NAME(Command):
     Shows the information about entered device name.
     """
     CMD = 0x67
-    GET, SET = True, False
+    GET, SET = True, True
     DATA = [Str('DEVICE_NAME')]
 
 
